@@ -1,8 +1,30 @@
+##############################################################################
+##
+# This file is part of Sardana
+##
+# http://www.sardana-controls.org/
+##
+# Copyright 2011 CELLS / ALBA Synchrotron, Bellaterra, Spain
+##
+# Sardana is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+##
+# Sardana is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+##
+# You should have received a copy of the GNU Lesser General Public License
+# along with Sardana.  If not, see <http://www.gnu.org/licenses/>.
+##
+##############################################################################
 
 """
-    Macro library containning diffractometer related macros for the macros 
+    Macro library containning diffractometer related macros for the macros
     server Tango device server as part of the Sardana project.
-    
+
 """
 
 # TODO: use taurus instead of PyTango API e.g. read_attribute,
@@ -13,7 +35,7 @@
 # using getDevice. However this getter seems to accept only the elements names
 # and not the full names.
 
-__all__ = ["addreflexion", "affine", "br", "ca", "caa", "ci", "computeub",
+__all__ = ["addreflection", "affine", "br", "ca", "caa", "ci", "computeub",
            "freeze", "getmode", "hklscan", "hscan", "kscan", "latticecal",
            "loadcrystal", "lscan", "newcrystal", "or0", "or1", "orswap",
            "pa", "savecrystal", "setaz", "setlat", "setmode", "setor0",
@@ -33,7 +55,8 @@ from taurus.core.util.log import Logger
 
 logger = Logger.getLogger("MacroManager")
 
-logger.info("Diffractometer macros are at early stage. They can slightly change. Macro luppsi is not tested.")
+logger.info(
+    "Diffractometer macros are at early stage. They can slightly change. Macro luppsi is not tested.")
 
 
 class _diffrac:
@@ -74,7 +97,7 @@ class _diffrac:
                 self.angle_names.append("omega")
                 self.angle_names.append("chi")
                 self.angle_names.append("phi")
-                self.angle_names.append("theta")
+                self.angle_names.append("tth")
             elif self.nb_motors == 6:
                 self.angle_names.append("mu")
                 self.angle_names.append("omega")
@@ -84,11 +107,25 @@ class _diffrac:
                 self.angle_names.append("delta")
 
         if self.nb_motors == 4:
-            self.labelmotor = {'Omega': "omega",
-                               'Chi': "chi", 'Phi': "phi", 'Theta': "theta"}
+            self.labelmotor = {'Omega': self.angle_names[0],
+                               'Chi': self.angle_names[1],
+                               'Phi': self.angle_names[2],
+                               'Tth': self.angle_names[3]}
         elif self.nb_motors == 6:
-            self.labelmotor = {'Mu': "mu", 'Theta': "omega", 'Chi': "chi",
-                               'Phi': "phi", 'Gamma': "gamma", 'Delta': "delta"}
+            self.labelmotor = {'Mu': self.angle_names[0],
+                               'Theta': self.angle_names[1],
+                               'Chi': self.angle_names[2],
+                               'Phi': self.angle_names[3],
+                               'Gamma': self.angle_names[4],
+                               'Delta': self.angle_names[5]}
+        elif self.nb_motors == 7:
+            self.labelmotor = {'Omega_t': self.angle_names[0],
+                               'Mu': self.angle_names[1],
+                               'Omega': self.angle_names[2],
+                               'Chi': self.angle_names[3],
+                               'Phi': self.angle_names[4],
+                               'Gamma': self.angle_names[5],
+                               'Delta': self.angle_names[6]}
 
         prop = self.diffrac.get_property(['DiffractometerType'])
         for v in prop['DiffractometerType']:
@@ -134,7 +171,7 @@ class _diffrac:
             pass
 
         hkl = []
-        if reflections != None:
+        if reflections is not None:
             for i in range(1, 4):
                 hkl.append(reflections[0][i])
 
@@ -149,7 +186,7 @@ class _diffrac:
             pass
 
         hkl = []
-        if reflections != None:
+        if reflections is not None:
             if len(reflections) > 1:
                 for i in range(1, 4):
                     hkl.append(reflections[1][i])
@@ -173,9 +210,9 @@ class _diffrac:
             return regx.sub(repl, ch)
 
 class br(Macro, _diffrac):
-    """Move the diffractometer to the reciprocal space coordinates given by 
-    H, K and L. 
-    If a fourth parameter is given, the combination of angles to be set is 
+    """Move the diffractometer to the reciprocal space coordinates given by
+    H, K and L.
+    If a fourth parameter is given, the combination of angles to be set is
     the correspondig to the given index. The index of the
     angles combinations are then changed."""
 
@@ -194,7 +231,9 @@ class br(Macro, _diffrac):
         _diffrac.prepare(self)
 
     def run(self, H, K, L, AnglesIndex, FlagNotBlocking, FlagPrinting):
-        h_idx = 0; k_idx = 1; l_idx = 2
+        h_idx = 0
+        k_idx = 1
+        l_idx = 2
 
         if AnglesIndex != -1:
             sel_tr = AnglesIndex
@@ -243,7 +282,7 @@ class br(Macro, _diffrac):
 
 
 class ubr(Macro, _diffrac):
-    """Move the diffractometer to the reciprocal space coordinates given by 
+    """Move the diffractometer to the reciprocal space coordinates given by
     H, K and L und update.
     """
 
@@ -290,7 +329,7 @@ class _ca(Macro, _diffrac):
         else:
             start_range = Trajectory
             end_range = Trajectory + 1
-            
+
         for i in range(int(start_range), int(end_range)):
             angles_list = self.diffrac.trajectorylist[i]
             self.output("")
@@ -306,7 +345,7 @@ class _ca(Macro, _diffrac):
             except:
                 self.warning(
                     "Not able to read psi. Check if environment Psi is defined")
-                
+
             self.output("Wavelength =  %7.5f" % (self.diffrac.WaveLength))
             self.output("")
 
@@ -316,12 +355,40 @@ class _ca(Macro, _diffrac):
                 str_pos[name] = "%7.5f" % angles_list[j]
                 j = j + 1
 
-            self.output("%10s %11s %12s %11s %10s %11s" %
-                        ("Delta", "Theta", "Chi", "Phi", "Mu", "Gamma"))
-            self.output("%10s %11s %12s %11s %10s %11s" %
-                        (str_pos[self.labelmotor["Delta"]], str_pos[self.labelmotor["Theta"]], str_pos[self.labelmotor["Chi"]], str_pos[self.labelmotor["Phi"]], str_pos[self.labelmotor["Mu"]], str_pos[self.labelmotor["Gamma"]]))
+            if self.nb_motors == 6:
+                self.output("%10s %11s %12s %11s %10s %11s" %
+                            ("Delta", "Theta", "Chi", "Phi",
+                             "Mu", "Gamma"))
+                self.output("%10s %11s %12s %11s %10s %11s" %
+                            (str_pos[self.labelmotor["Delta"]],
+                             str_pos[self.labelmotor["Theta"]],
+                             str_pos[self.labelmotor["Chi"]],
+                             str_pos[self.labelmotor["Phi"]],
+                             str_pos[self.labelmotor["Mu"]],
+                             str_pos[self.labelmotor["Gamma"]]))
+            elif self.nb_motors == 4:
+                self.output("%10s %11s %12s %11s" %
+                            ("Tth", "Omega", "Chi", "Phi"))
+                self.output("%10s %11s %12s %11s" %
+                            (str_pos[self.labelmotor["Tth"]],
+                             str_pos[self.labelmotor["Omega"]],
+                             str_pos[self.labelmotor["Chi"]],
+                             str_pos[self.labelmotor["Phi"]]))
+            elif self.nb_motors == 7:
+                self.output("%10s %11s %12s %11s %10s %11s %11s" %
+                            ("Omega_t", "Mu", "Omega", "Chi",
+                             "Phi", "Gamma", "Delta"))
+                self.output("%10s %11s %12s %11s %10s %11s %11s" %
+                            (str_pos[self.labelmotor["Omega_t"]],
+                             str_pos[self.labelmotor["Mu"]],
+                             str_pos[self.labelmotor["Omega"]],
+                             str_pos[self.labelmotor["Chi"]],
+                             str_pos[self.labelmotor["Phi"]],
+                             str_pos[self.labelmotor["Gamma"]],
+                             str_pos[self.labelmotor["Delta"]]))
+
+
 
-            
 class ca(Macro, _diffrac):
     """Calculate motor positions for given H K L according to the current
     operation mode (trajectory 0)."""
@@ -402,7 +469,7 @@ class pa(Macro, _diffrac):
         _diffrac.prepare(self)
 
     def run(self):
-        
+
         str_type = "Eulerian 6C"
         if self.type == 'E4CV':
             str_type = "Eulerian 4C Vertical"
@@ -421,7 +488,7 @@ class pa(Macro, _diffrac):
         reflections = self.diffrac.reflectionlist
 
         nb_ref = 0
-        if reflections != None:
+        if reflections is not None:
             for ref in reflections:
                 if nb_ref < len(self.suffix):
                     sf = self.suffix[nb_ref]
@@ -431,14 +498,32 @@ class pa(Macro, _diffrac):
                             (nb_ref + 1, sf, ref[0]))
                 #self.output("    Affinement, Relevance : %d %d" % (ref[4], ref[5]))
                 if len(ref) > 10:
-                    self.output("    %s %s %s %s %s %s: %s %s %s %s %s %s" % (self.angle_names[5], self.angle_names[1], self.angle_names[2], self.angle_names[3], self.angle_names[4], self.angle_names[0], _diffrac.fl(
-                        self, str(ref[11])), _diffrac.fl(self, str(ref[7])), _diffrac.fl(self, str(ref[8])), _diffrac.fl(self, str(ref[9])), _diffrac.fl(self, str(ref[10])), _diffrac.fl(self, str(ref[6]))))
+                    self.output("    %s %s %s %s %s %s: %s %s %s %s %s %s" %
+                                (self.angle_names[5], self.angle_names[1],
+                                 self.angle_names[2], self.angle_names[3],
+                                 self.angle_names[4], self.angle_names[0],
+                                 _diffrac.fl(self, str(ref[11])),
+                                 _diffrac.fl(self, str(ref[7])),
+                                 _diffrac.fl(self, str(ref[8])),
+                                 _diffrac.fl(self, str(ref[9])),
+                                 _diffrac.fl(self, str(ref[10])),
+                                 _diffrac.fl(self, str(ref[6]))))
                 else:
-                    self.output("    %s %s %s %s: %s %s %s %s" % (self.angle_names[0], self.angle_names[1], self.angle_names[2], self.angle_names[
-                                3], _diffrac.fl(self, str(ref[6])), _diffrac.fl(self, str(ref[7])), _diffrac.fl(self, str(ref[8])), _diffrac.fl(self, str(ref[9]))))
+                    self.output("    %s %s %s %s: %s %s %s %s" %
+                                (self.angle_names[0], self.angle_names[1],
+                                 self.angle_names[2], self.angle_names[3],
+                                 _diffrac.fl(self, str(ref[6])),
+                                 _diffrac.fl(self, str(ref[7])),
+                                 _diffrac.fl(self, str(ref[8])),
+                                 _diffrac.fl(self, str(ref[9]))))
                 nb_ref = nb_ref + 1
-                self.output(" %33s  %s %s %s" % ("H K L =", _diffrac.fl(self, str(
-                    ref[1])), _diffrac.fl(self, str(ref[2])), _diffrac.fl(self, str(ref[3]))))
+                self.output(" %33s  %s %s %s" % ("H K L =",
+                                                 _diffrac.fl(
+                                                     self, str(ref[1])),
+                                                 _diffrac.fl(
+                                                     self, str(ref[2])),
+                                                 _diffrac.fl(
+                                                     self, str(ref[3]))))
                 self.output("")
 
 
@@ -447,7 +532,10 @@ class pa(Macro, _diffrac):
         self.output("%32s = %s %s %s / %s %s %s" % ("real space", self.diffrac.a,
                                                     self.diffrac.b, self.diffrac.c, _diffrac.fl(
                                                         self, str(self.diffrac.alpha)),
-                                                    _diffrac.fl(self, str(self.diffrac.beta)), _diffrac.fl(self, str(self.diffrac.gamma))))
+                                                    _diffrac.fl(self, str(
+                                                        self.diffrac.beta)),
+                                                    _diffrac.fl(self, str(
+                                                        self.diffrac.gamma))))
 
         self.output("")
         self.output("  Azimuthal reference:")
@@ -467,10 +555,11 @@ class pa(Macro, _diffrac):
 class wh(Macro, _diffrac):
     """Show principal axes and reciprocal space positions.
 
-    Prints the current reciprocal space coordinates (H K L) and the user 
-    positions of the principal motors. Depending on the diffractometer geometry, 
-    other parameters such as the angles of incidence and reflection (ALPHA and 
-    BETA) and the incident wavelength (LAMBDA) may be displayed."""
+    Prints the current reciprocal space coordinates (H K L) and the user
+    positions of the principal motors. Depending on the diffractometer
+    geometry, other parameters such as the angles of incidence and
+    reflection (ALPHA and BETA) and the incident wavelength (LAMBDA)
+    may be displayed."""
 
     def prepare(self):
         _diffrac.prepare(self)
@@ -484,7 +573,8 @@ class wh(Macro, _diffrac):
 
         self.output("")
         self.output("%s %s %3s %9.5f %9.5f %9.5f " %
-                    ("H", "K", "L = ", self.h_device.position, self.k_device.position, self.l_device.position))
+                    ("H", "K", "L = ", self.h_device.position,
+                     self.k_device.position, self.l_device.position))
 
         if self.diffrac.psirefh == -999:
             self.output("")
@@ -523,7 +613,7 @@ class wh(Macro, _diffrac):
 
         parameter_names = self.diffrac.modeparametersnames
 
-        if parameter_names != None:
+        if parameter_names is not None:
             i = 0
             for par in parameter_names:
                 if par == "psi":
@@ -535,23 +625,63 @@ class wh(Macro, _diffrac):
         self.output("%s %7.5f" % ("Wavelength = ", self.diffrac.WaveLength))
         self.output("")
 
-        str_pos1 = "%7.5f" % self.getDevice(
-            self.angle_device_names[self.labelmotor["Delta"]]).Position
-        str_pos2 = "%7.5f" % self.getDevice(
-            self.angle_device_names[self.labelmotor["Theta"]]).Position
-        str_pos3 = "%7.5f" % self.getDevice(
-            self.angle_device_names[self.labelmotor["Chi"]]).Position
-        str_pos4 = "%7.5f" % self.getDevice(
-            self.angle_device_names[self.labelmotor["Phi"]]).Position
-        str_pos5 = "%7.5f" % self.getDevice(
-            self.angle_device_names[self.labelmotor["Mu"]]).Position
-        str_pos6 = "%7.5f" % self.getDevice(
-            self.angle_device_names[self.labelmotor["Gamma"]]).Position
-
-        self.output("%10s %11s %12s %11s %10s %11s" %
-                    ("Delta", "Theta", "Chi", "Phi", "Mu", "Gamma"))
-        self.output("%10s %11s %12s %11s %10s %11s" %
-                    (str_pos1, str_pos2, str_pos3, str_pos4, str_pos5, str_pos6))
+        if self.nb_motors == 6:
+            str_pos1 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Delta"]]).Position
+            str_pos2 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Theta"]]).Position
+            str_pos3 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Chi"]]).Position
+            str_pos4 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Phi"]]).Position
+            str_pos5 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Mu"]]).Position
+            str_pos6 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Gamma"]]).Position
+            self.output("%10s %11s %12s %11s %10s %11s" %
+                        (self.labelmotor["Delta"], self.labelmotor["Theta"],
+                         self.labelmotor["Chi"], self.labelmotor["Phi"],
+                         self.labelmotor["Mu"], self.labelmotor["Gamma"]))
+            self.output("%10s %11s %12s %11s %10s %11s" %
+                        (str_pos1, str_pos2, str_pos3, str_pos4, str_pos5,
+                         str_pos6))
+        elif self.nb_motors == 4:
+            str_pos1 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Tth"]]).Position
+            str_pos2 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Omega"]]).Position
+            str_pos3 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Chi"]]).Position
+            str_pos4 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Phi"]]).Position
+            self.output("%10s %11s %12s %11s" %
+                        (self.labelmotor["Tth"], self.labelmotor["Omega"],
+                         self.labelmotor["Chi"], self.labelmotor["Phi"]))
+            self.output("%10s %11s %12s %11s" %
+                        (str_pos1, str_pos2, str_pos3, str_pos4))
+        elif self.nb_motors == 7:
+            str_pos1 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Omega_t"]]).Position
+            str_pos2 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Mu"]]).Position
+            str_pos3 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Omega"]]).Position
+            str_pos4 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Chi"]]).Position
+            str_pos5 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Phi"]]).Position
+            str_pos6 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Gamma"]]).Position
+            str_pos7 = "%7.5f" % self.getDevice(
+                self.angle_device_names[self.labelmotor["Delta"]]).Position
+            self.output("%10s %11s %12s %11s %10s %11s %11s" %
+                        (self.labelmotor["Omega_t"], self.labelmotor["Mu"],
+                         self.labelmotor["Omega"], self.labelmotor["Chi"],
+                         self.labelmotor["Phi"], self.labelmotor["Gamma"],
+                         self.labelmotor["Delta"]))
+            self.output("%10s %11s %12s %11s %10s %11s %11s" %
+                        (str_pos1, str_pos2, str_pos3, str_pos4, str_pos5,
+                         str_pos6, str_pos7))
 
         self.setEnv('Q', [self.h_device.position, self.k_device.position,
                           self.l_device.position, self.diffrac.WaveLength])
@@ -855,7 +985,8 @@ class setorn(iMacro, _diffrac):
 
     def run(self, ref_id, H, K, L, mu, theta, chi, phi, gamma, delta):
 
-        if delta == -999:
+        if (delta == -999 and self.nb_motors == 6) or (
+                phi == -999 and self.nb_motors == 4):
             reflections = []
             try:
                 reflections = self.diffrac.reflectionlist
@@ -863,22 +994,22 @@ class setorn(iMacro, _diffrac):
                 pass
             tmp_ref = {}
             hkl_names = ["h", "k", "l"]
-            if reflections != None:
+            if reflections is not None:
                 if len(reflections) > ref_id:
                     for i in range(1, 4):
                         tmp_ref[hkl_names[i - 1]] = reflections[ref_id][i]
-                    for i in range(6, 12):
-                        tmp_ref[self.angle_names[i - 6]
-                                ] = reflections[ref_id][i]
+                    for i in range(6, 6 + self.nb_motors):
+                        tmp_ref[
+                            self.angle_names[i - 6]] = reflections[ref_id][i]
                 else:
                     for i in range(0, 3):
                         tmp_ref[hkl_names[i]] = 0
-                    for i in range(0, 6):
+                    for i in range(0, self.nb_motors):
                         tmp_ref[self.angle_names[i]] = 0
             else:
                 for i in range(0, 3):
                     tmp_ref[hkl_names[i]] = 0
-                for i in range(0, 6):
+                for i in range(0, self.nb_motors):
                     tmp_ref[self.angle_names[i]] = 0
 
             self.output("")
@@ -890,18 +1021,31 @@ class setorn(iMacro, _diffrac):
                 ref_txt = "reflection " + str(ref_id)
 
             self.output("Enter %s angles" % ref_txt)
-            delta = float(self.input(" Delta?", default_value=tmp_ref[
-                          "delta"], data_type=Type.String))
-            theta = float(self.input(" Theta? ", default_value=tmp_ref[
+            if self.nb_motors == 6:
+                delta = float(self.input(" Delta?", default_value=tmp_ref[
+                    "delta"], data_type=Type.String))
+
+                theta = float(self.input(" Theta? ", default_value=tmp_ref[
                           "omega"], data_type=Type.String))
-            chi = float(self.input(" Chi?", default_value=tmp_ref[
-                        "chi"], data_type=Type.String))
-            phi = float(self.input(" Phi?", default_value=tmp_ref[
-                        "phi"], data_type=Type.String))
-            gamma = float(self.input(" Gamma?", default_value=tmp_ref[
-                          "gamma"], data_type=Type.String))
-            mu = float(self.input(" Mu?", default_value=tmp_ref[
-                       "mu"], data_type=Type.String))
+                chi = float(self.input(" Chi?", default_value=tmp_ref[
+                    "chi"], data_type=Type.String))
+                phi = float(self.input(" Phi?", default_value=tmp_ref[
+                    "phi"], data_type=Type.String))
+                gamma = float(self.input(" Gamma?", default_value=tmp_ref[
+                    "gamma"], data_type=Type.String))
+                mu = float(self.input(" Mu?", default_value=tmp_ref[
+                    "mu"], data_type=Type.String))
+            if self.nb_motors == 4:
+
+                omega = float(self.input(" Omega?", default_value=tmp_ref[
+                    "omega"], data_type=Type.String))
+                chi = float(self.input(" Chi?", default_value=tmp_ref[
+                    "chi"], data_type=Type.String))
+                phi = float(self.input(" Phi?", default_value=tmp_ref[
+                    "phi"], data_type=Type.String))
+                tth = float(self.input(" Tth?", default_value=tmp_ref[
+                    "omega"], data_type=Type.String))
+
 
             self.output("")
             self.output("Enter %s HKL coordinates" % ref_txt)
@@ -935,8 +1079,14 @@ class setorn(iMacro, _diffrac):
 
         # Adjust angles
 
-        self.angle_values = {"mu": mu, "omega": theta,
-                             "chi": chi, "phi": phi, "gamma": gamma, "delta": delta}
+        if self.nb_motors == 6:
+            self.angle_values = {"mu": mu, "omega": theta,
+                                 "chi": chi, "phi": phi, "gamma": gamma,
+                                 "delta": delta}
+        elif self.nb_motors == 4:
+            self.angle_values = {"omega": omega, "chi": chi,
+                                 "phi": phi, "tth": tth}
+
 
         values = []
         values.append(ref_id)
@@ -1013,10 +1163,10 @@ class computeub(Macro, _diffrac):
     def run(self):
 
         reflections = self.diffrac.reflectionlist
-        if reflections != None:
+        if reflections is not None:
             if len(reflections) > 1:
                 self.output("Computing UB with reflections 0 and 1")
-                values = [0,1]
+                values = [0, 1]
                 self.diffrac.write_attribute("ComputeUB", values)
                 self.execMacro('savecrystal')
             else:
@@ -1049,9 +1199,9 @@ class addreflection(Macro, _diffrac):
 
 class affine(Macro, _diffrac):
     """Affine current crystal.
-    Fine tunning of lattice parameters and UB matrix based on 
-    current crystal reflections. Reflections with affinement 
-    set to 0 are not used. A new crystal with the post fix 
+    Fine tunning of lattice parameters and UB matrix based on
+    current crystal reflections. Reflections with affinement
+    set to 0 are not used. A new crystal with the post fix
     (affine) is created and set as current crystal"""
 
     def prepare(self):
@@ -1165,7 +1315,8 @@ class hscan(aNscan, Macro, _diffrac):
 
     def prepare(self, start_pos, final_pos, nr_interv, integ_time):
         _diffrac.prepare(self)
-        aNscan._prepare(self, [self.h_device], [start_pos], [final_pos], nr_interv, integ_time)
+        aNscan._prepare(self, [self.h_device], [start_pos],
+                        [final_pos], nr_interv, integ_time)
 
 
 class kscan(aNscan, Macro, _diffrac):
@@ -1180,7 +1331,8 @@ class kscan(aNscan, Macro, _diffrac):
 
     def prepare(self, start_pos, final_pos, nr_interv, integ_time):
         _diffrac.prepare(self)
-        aNscan._prepare(self, [self.k_device], [start_pos], [final_pos], nr_interv, integ_time)
+        aNscan._prepare(self, [self.k_device], [start_pos],
+                        [final_pos], nr_interv, integ_time)
 
 
 class lscan(aNscan, Macro, _diffrac):
@@ -1195,7 +1347,8 @@ class lscan(aNscan, Macro, _diffrac):
 
     def prepare(self, start_pos, final_pos, nr_interv, integ_time):
         _diffrac.prepare(self)
-        aNscan._prepare(self, [self.l_device], [start_pos], [final_pos], nr_interv, integ_time)
+        aNscan._prepare(self, [self.l_device], [start_pos],
+                        [final_pos], nr_interv, integ_time)
 
 
 class hklscan(aNscan, Macro, _diffrac):
@@ -1214,14 +1367,18 @@ class hklscan(aNscan, Macro, _diffrac):
 
     def prepare(self, h_start_pos, h_final_pos, k_start_pos, k_final_pos, l_start_pos, l_final_pos, nr_interv, integ_time):
         _diffrac.prepare(self)
-        aNscan._prepare(self, [self.h_device, self.k_device, self.l_device], [h_start_pos, k_start_pos, l_start_pos], [h_final_pos, k_final_pos, l_final_pos], nr_interv, integ_time)
-        
+        aNscan._prepare(self, [self.h_device, self.k_device, self.l_device],
+                        [h_start_pos, k_start_pos, l_start_pos], [h_final_pos,
+                                                                  k_final_pos,
+                                                                  l_final_pos],
+                        nr_interv, integ_time)
+
 
 
 class th2th(Macro):
     """th2th - scan:
 
-    Relative scan around current position in del and th with d_th=2*d_delta    
+    Relative scan around current position in del and th with d_th=2*d_delta
     """
 
     param_def = [
@@ -1268,7 +1425,7 @@ class luppsi(Macro, _diffrac):
 
     Relative scan psi angle
 
-    [TODO] Still not tested    
+    [TODO] Still not tested
     """
 
     param_def = [
@@ -1386,7 +1543,7 @@ class loadcrystal(iMacro, _diffrac):
         if len(res) == 0:
             self.output("No crystals available in set directory. Nothing done")
             return
-        
+
         i = 1
         for filename in res:
             filename = filename.split('.')[0]
@@ -1484,7 +1641,7 @@ class _blockprintmove(Macro, _diffrac):
         _diffrac.prepare(self)
 
     def run(self, flagprint):
-        
+
         moving = 1
         tmp_dev = {}
         for angle in self.angle_names:
@@ -1492,7 +1649,12 @@ class _blockprintmove(Macro, _diffrac):
         while(moving):
             moving = 0
             for angle in self.angle_names:
-                if tmp_dev[angle].state() == 6:
+                # TODO: For Taurus 4 / Taurus 3 compatibility
+                if hasattr(mot_dev, "stateObj"):
+                    angle_state = tmp_dev[angle].stateObj.read().rvalue
+                else:
+                    angle_state = tmp_dev[angle].state()
+                if angle_state == 6:
                     moving = 1
             if flagprint == 1:
                 self.outputBlock(" %7.5f  %7.5f  %7.5f" % (
@@ -1511,17 +1673,18 @@ class _diff_scan(Macro):
     This macro is internal and reserved to the hkl infrastucture.
     """
     param_def = [
-       ['motor',      Type.Motor,   None, 'Motor to move'],
-       ['start_pos',  Type.Float,   None, 'Scan start position'],
-       ['final_pos',  Type.Float,   None, 'Scan final position'],
-       ['nr_interv',  Type.Integer, None, 'Number of scan intervals'],
-       ['integ_time', Type.Float,   None, 'Integration time'],
-       ['channel',    Type.ExpChannel,   None, 'Channel to analize']
+        ['motor',      Type.Motor,   None, 'Motor to move'],
+        ['start_pos',  Type.Float,   None, 'Scan start position'],
+        ['final_pos',  Type.Float,   None, 'Scan final position'],
+        ['nr_interv',  Type.Integer, None, 'Number of scan intervals'],
+        ['integ_time', Type.Float,   None, 'Integration time'],
+        ['channel',    Type.ExpChannel,   None, 'Channel to analize']
     ]
 
     def run(self, motor, start_pos, final_pos, nr_interv, integ_time, channel):
 
-        ascan, pars= self.createMacro("ascan",motor, start_pos, final_pos, nr_interv, integ_time)
+        ascan, pars = self.createMacro(
+            "ascan", motor, start_pos, final_pos, nr_interv, integ_time)
         self.runMacro(ascan)
 
         channel_fullname = channel.getFullName()
